Struct SecretEncryptedData
#[non_exhaustive]pub struct SecretEncryptedData;Expand description
Encrypted data for a secret storage encryption algorithm.
This type cannot be constructed, it is only used for its semantic value and is meant to be used
with the Raw::cast() and Raw::deserialize_as() APIs.
It can be cast to or from the following types:
Convenience methods are also available for casting encrypted data from or to known compatible types.
Implementations
impl SecretEncryptedData
impl SecretEncryptedData
pub fn new<T>(encrypted_data: Raw<T>) -> Raw<SecretEncryptedData>where
T: JsonCastable<SecretEncryptedData>,
pub fn new<T>(encrypted_data: Raw<T>) -> Raw<SecretEncryptedData>where
T: JsonCastable<SecretEncryptedData>,
Construct a Raw<SecretEncryptedData> by casting the given serialized encrypted data.
pub fn serialize<T>(
encrypted_data: &T,
) -> Result<Raw<SecretEncryptedData>, Error>where
T: Serialize + JsonCastable<SecretEncryptedData>,
pub fn serialize<T>(
encrypted_data: &T,
) -> Result<Raw<SecretEncryptedData>, Error>where
T: Serialize + JsonCastable<SecretEncryptedData>,
Serialize the given encrypted data as a Raw<SecretEncryptedData>.
pub fn deserialize_as_aes_hmac_sha2(
encrypted_data: &Raw<SecretEncryptedData>,
) -> Result<AesHmacSha2EncryptedData, Error>
pub fn deserialize_as_aes_hmac_sha2( encrypted_data: &Raw<SecretEncryptedData>, ) -> Result<AesHmacSha2EncryptedData, Error>
Deserialize the given data encrypted with the m.secret_storage.v1.aes-hmac-sha2 algorithm.